==> v0.2.24.tar.gz: submit-social-housing-lettings-and-sales-data/spec/models/form/sales/questions/buyer1_ethnic_background_mixed_spec.rb <==
require "rails_helper"

RSpec.describe Form::Sales::Questions::Buyer1EthnicBackgroundMixed, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page) }

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("ethnic")
  end

  it "has the correct header" do
    expect(question.header).to eq("Which of the following best describes the buyer 1’s Mixed or Multiple ethnic groups background?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Buyer 1’s ethnic background")
  end

  it "has the correct type" do
    expect(question.type).to eq("radio")
  end

  it "is not marked as derived" do
    expect(question.derived?).to be false
  end

  it "has the correct hint_text" do
    expect(question.hint_text).to eq("Buyer 1 is the person in the household who does the most paid work. If it’s a joint purchase and the buyers do the same amount of paid work, buyer 1 is whoever is the oldest.")
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "4" => { "value" => "White and Black Caribbean" },
      "5" => { "value" => "White and Black African" },
      "6" => { "value" => "White and Asian" },
      "7" => { "value" => "Any other Mixed or Multiple ethnic background" },
    })
  end
end

==> v0.4.69.tar.gz: submit-social-housing-lettings-and-sales-data/spec/models/form/sales/questions/buyer1_ethnic_background_mixed_spec.rb <==
require "rails_helper"

RSpec.describe Form::Sales::Questions::Buyer1EthnicBackgroundMixed, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page, subsection: instance_double(Form::Subsection, form: instance_double(Form, start_date: Time.zone.local(2023, 4, 1), start_year_after_2024?: false))) }

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("ethnic")
  end

  it "has the correct header" do
    expect(question.header).to eq("Which of the following best describes buyer 1’s Mixed or Multiple ethnic groups background?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Buyer 1’s ethnic background")
  end

  it "has the correct type" do
    expect(question.type).to eq("radio")
  end

  it "is not marked as derived" do
    expect(question.derived?(nil)).to be false
  end

  it "has the correct hint_text" do
    expect(question.hint_text).to eq("Buyer 1 is the person in the household who does the most paid work. If it’s a joint purchase and the buyers do the same amount of paid work, buyer 1 is whoever is the oldest.")
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "4" => { "value" => "White and Black Caribbean" },
      "5" => { "value" => "White and Black African" },
      "6" => { "value" => "White and Asian" },
      "7" => { "value" => "Any other Mixed or Multiple ethnic background" },
    })
  end

  it "has the correct check_answers_card_number" do
    expect(question.check_answers_card_number).to eq(1)
  end
end
